@@ -33,22 +33,22 @@ public class Version {
         "java";
 
     private static final String java_version =
-        "1.7.0_231";
+        "1.7.0_261";
 
     private static final String java_runtime_name =
         "OpenJDK Runtime Environment";
 
     private static final String java_runtime_version =
-        "1.7.0_231-b01";
+        "1.7.0_261-b02";
 
     private static final String jdk_derivative_name =
-        "IcedTea 2.6.19";
+        "IcedTea 2.6.22";
 
     private static final String distro_name =
         "linux-gnueabihf";
 
     private static final String distro_package_version =
-        "Arch Linux ARM build 7.u231_2.6.19-1.1-armv7h";
+        "Arch Linux ARM build 7.u261_2.6.22-1-armv7h";
 
     private static final String jdk_revid =
         "";
